==> estateplat-common-1.2.4-20200717.083615-395-sources.jar: cn/gtmap/estateplat/model/config/BdcCxBdcdyZt.java <==
package cn.gtmap.estateplat.model.config;
/*
 * @author <a href="mailto:huangzijian@gtmap.cn">huangzijian</a>
 * @version 1.0, 2017/11/23
 * @description 
 */

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

@Table(name="bdc_cx_bdcdy_zt")
public class BdcCxBdcdyZt implements Serializable, InsertVo {
    @Id
    private String ztid;
    private String bdcdyh;
    private String bdclx;
    private String bdcdyzt;
    private String djzt;
    private String qlr;
    private String zl;
    private Double mj;
    private String yt;
    private Integer xszjgcdycs;
    private Integer xsygcs;
    private Integer xsydyacs;
    private Integer xsdyacs;
    private Integer xsycfcs;
    private Integer xscfcs;
    private Integer xsyycs;
    private Integer xsdyics;
    private Integer xssdcs;
    private Integer ks;
    private Integer ys;
    private String ly;
    private String sfba;//是否备案
    private String bdcqzh;//不动产权证号

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getZtid() {
        return ztid;
    }

    public void setZtid(String ztid) {
        this.ztid = ztid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getBdcdyzt() {
        return bdcdyzt;
    }

    public void setBdcdyzt(String bdcdyzt) {
        this.bdcdyzt = bdcdyzt;
    }

    public String getDjzt() {
        return djzt;
    }

    public void setDjzt(String djzt) {
        this.djzt = djzt;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public Double getMj() {
        return mj;
    }

    public void setMj(Double mj) {
        this.mj = mj;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public Integer getXszjgcdycs() {
        return xszjgcdycs;
    }

    public void setXszjgcdycs(Integer xszjgcdycs) {
        this.xszjgcdycs = xszjgcdycs;
    }

    public Integer getXsygcs() {
        return xsygcs;
    }

    public void setXsygcs(Integer xsygcs) {
        this.xsygcs = xsygcs;
    }

    public Integer getXsydyacs() {
        return xsydyacs;
    }

    public void setXsydyacs(Integer xsydyacs) {
        this.xsydyacs = xsydyacs;
    }

    public Integer getXsdyacs() {
        return xsdyacs;
    }

    public void setXsdyacs(Integer xsdyacs) {
        this.xsdyacs = xsdyacs;
    }

    public Integer getXsycfcs() {
        return xsycfcs;
    }

    public void setXsycfcs(Integer xsycfcs) {
        this.xsycfcs = xsycfcs;
    }

    public Integer getXscfcs() {
        return xscfcs;
    }

    public void setXscfcs(Integer xscfcs) {
        this.xscfcs = xscfcs;
    }

    public Integer getXsyycs() {
        return xsyycs;
    }

    public void setXsyycs(Integer xsyycs) {
        this.xsyycs = xsyycs;
    }

    public Integer getXsdyics() {
        return xsdyics;
    }

    public void setXsdyics(Integer xsdyics) {
        this.xsdyics = xsdyics;
    }

    public Integer getXssdcs() {
        return xssdcs;
    }

    public void setXssdcs(Integer xssdcs) {
        this.xssdcs = xssdcs;
    }

    public Integer getKs() {
        return ks;
    }

    public void setKs(Integer ks) {
        this.ks = ks;
    }

    public Integer getYs() {
        return ys;
    }

    public void setYs(Integer ys) {
        this.ys = ys;
    }

    public String getLy() {
        return ly;
    }

    public void setLy(String ly) {
        this.ly = ly;
    }

    public String getSfba() {
        return sfba;
    }

    public void setSfba(String sfba) {
        this.sfba = sfba;
    }
}

==> estateplat-common-1.2.4-20201212.075713-587-sources.jar: cn/gtmap/estateplat/model/config/BdcCxBdcdyZt.java <==
package cn.gtmap.estateplat.model.config;
/*
 * @author <a href="mailto:huangzijian@gtmap.cn">huangzijian</a>
 * @version 1.0, 2017/11/23
 * @description 
 */

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

@Table(name="bdc_cx_bdcdy_zt")
public class BdcCxBdcdyZt implements Serializable, InsertVo {
    @Id
    private String ztid;
    private String bdcdyh;
    private String bdclx;
    private String bdcdyzt;
    private String djzt;
    private String qlr;
    private String zl;
    private Double mj;
    private String yt;
    private Integer xszjgcdycs;
    private Integer xsygcs;
    private Integer xsydyacs;
    private Integer xsdyacs;
    private Integer xsycfcs;
    private Integer xscfcs;
    private Integer xsyycs;
    private Integer xsdyics;
    private Integer xssdcs;
    private Integer ks;
    private Integer ys;
    private String ly;
    private String sfba;//是否备案
    private String bdcqzh;//不动产权证号
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 首次登记状态
     */
    private Integer scdjzt;

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getZtid() {
        return ztid;
    }

    public void setZtid(String ztid) {
        this.ztid = ztid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getBdcdyzt() {
        return bdcdyzt;
    }

    public void setBdcdyzt(String bdcdyzt) {
        this.bdcdyzt = bdcdyzt;
    }

    public String getDjzt() {
        return djzt;
    }

    public void setDjzt(String djzt) {
        this.djzt = djzt;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public Double getMj() {
        return mj;
    }

    public void setMj(Double mj) {
        this.mj = mj;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public Integer getXszjgcdycs() {
        return xszjgcdycs;
    }

    public void setXszjgcdycs(Integer xszjgcdycs) {
        this.xszjgcdycs = xszjgcdycs;
    }

    public Integer getXsygcs() {
        return xsygcs;
    }

    public void setXsygcs(Integer xsygcs) {
        this.xsygcs = xsygcs;
    }

    public Integer getXsydyacs() {
        return xsydyacs;
    }

    public void setXsydyacs(Integer xsydyacs) {
        this.xsydyacs = xsydyacs;
    }

    public Integer getXsdyacs() {
        return xsdyacs;
    }

    public void setXsdyacs(Integer xsdyacs) {
        this.xsdyacs = xsdyacs;
    }

    public Integer getXsycfcs() {
        return xsycfcs;
    }

    public void setXsycfcs(Integer xsycfcs) {
        this.xsycfcs = xsycfcs;
    }

    public Integer getXscfcs() {
        return xscfcs;
    }

    public void setXscfcs(Integer xscfcs) {
        this.xscfcs = xscfcs;
    }

    public Integer getXsyycs() {
        return xsyycs;
    }

    public void setXsyycs(Integer xsyycs) {
        this.xsyycs = xsyycs;
    }

    public Integer getXsdyics() {
        return xsdyics;
    }

    public void setXsdyics(Integer xsdyics) {
        this.xsdyics = xsdyics;
    }

    public Integer getXssdcs() {
        return xssdcs;
    }

    public void setXssdcs(Integer xssdcs) {
        this.xssdcs = xssdcs;
    }

    public Integer getKs() {
        return ks;
    }

    public void setKs(Integer ks) {
        this.ks = ks;
    }

    public Integer getYs() {
        return ys;
    }

    public void setYs(Integer ys) {
        this.ys = ys;
    }

    public String getLy() {
        return ly;
    }

    public void setLy(String ly) {
        this.ly = ly;
    }

    public String getSfba() {
        return sfba;
    }

    public void setSfba(String sfba) {
        this.sfba = sfba;
    }


    public Integer getScdjzt() {
        return scdjzt;
    }

    public void setScdjzt(Integer scdjzt) {
        this.scdjzt = scdjzt;
    }
}
